@@ -12,7 +12,7 @@ use XTM::generic;
 
 @ISA = qw(Exporter AutoLoader XTM::generic);
 @EXPORT = qw( );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =pod
 
@@ -28,6 +28,19 @@ XTM::instanceOf - trivial class definition
 
 Generic container for accessor functions.
 
+=cut
+
+sub xml {
+  my $self   = shift;
+  my $writer = shift;
+
+  $writer->startTag ('instanceOf');
+  $self->reference->xml ($writer);
+  $writer->endTag ('instanceOf');
+}
+
+=pod
+
 =head1 SEE ALSO
 
 L<XTM>
